import { Form, Input, message, Modal } from "antd"
import React from "react"
import dayjs from "dayjs"
import { randomString } from "@/utils/utils"

/**
 * 设置名称
 * @returns 
 */
interface Props {
    visible?: boolean,
    onClose?: () => void,
    onChange?: (data: any) => void
    ajax?: any
}
const SubmitModal: React.FC<Props> = (props) => {

    /********************/
    const { visible, onClose, onChange, ajax } = props
    const [form] = Form.useForm()
    /********************/

    const handleOk = () => {
        form.validateFields().then((values) => {
            const params = JSON.parse(JSON.stringify(values))
            onChange?.(params)
        }).catch(() => {
            form.submit()
        });
    }


    return <Modal
        title={<strong style={{ fontSize: 20 }}>提交</strong>}
        open={visible}
        confirmLoading={ajax?.loading}
        onCancel={onClose}
        maskClosable={false}
        onOk={handleOk}
    >
        <Form
            name="basicSubmit"
            form={form}
            labelCol={{ span: 4 }}
            autoComplete="off"
            scrollToFirstError={{
                behavior: 'smooth',
                block: 'center'
            }}
            onFinishFailed={({ errorFields }) => {
                message.error(errorFields?.[0]?.errors?.[0])
            }}
            colon={false}
            labelAlign="left"
            initialValues={{
                projectName: '任务' + dayjs().format('MMDDHHmmss') + '_' + randomString(true, 3, 5)
            }}
        >
            <Form.Item label={<strong>任务名称</strong>} name="projectName" rules={[{ required: true, message: '请输入任务名称!' }]}>
                <Input placeholder="请输入任务名称" />
            </Form.Item>
        </Form>
    </Modal>
}

export default React.memo(SubmitModal)